﻿using Syncfusion.SfPdfViewer.XForms;
using System;
using System.Collections.Generic;
using System.Globalization;
using System.IO;
using System.Linq;
using System.Reflection;
using System.Text;
using System.Threading.Tasks;

using Xamarin.Forms;
using Xamarin.Forms.Xaml;

namespace PdfTabViewer
{
    [XamlCompilation(XamlCompilationOptions.Compile)]
    public partial class PdfPage : ContentPage
    {
        public PdfPage()
        {
            InitializeComponent();
            pageNumberEntry.Completed += OnCurrentPageEntryCompleted;
            pdfViewerControl.PageChanged += OnPdfViewerControlPageChanged;
            loadPdfButton.Clicked += OnLoadPdfButtonClicked;
            pageNumberEntry.Text = "1";

        }

        private void LoadDocument()
        {
            Stream fileStream = typeof(App).GetTypeInfo().Assembly.GetManifestResourceStream("PdfTabViewer.Assets.GIS Succinctly.pdf");
            fileStream.Position = 0;

            pdfViewerControl.LoadDocument(fileStream);

            pageCountLabel.Text = pdfViewerControl.PageCount.ToString(); // !! always 0 on UWP            
        }

        private void OnLoadPdfButtonClicked(object sender, EventArgs e)
        {
            if (pdfViewerControl.InputFileStream == null)
                LoadDocument();
        }

        private void OnPdfViewerControlPageChanged(object sender, PageChangedEventArgs args)
        {
            pageNumberEntry.Text = args.PageNumber.ToString();
            if (Device.OS == TargetPlatform.Windows)
                pageCountLabel.Text = pdfViewerControl.PageCount.ToString(); // workaround for UWP that always report 0 in OnAppearing
        }

        private void OnCurrentPageEntryCompleted(object sender, EventArgs e)
        {
            int pageNumber = 1;
            if (int.TryParse(((sender as Entry).Text), NumberStyles.Integer, CultureInfo.InvariantCulture, out pageNumber))
            {
                if ((sender as Entry) != null && pageNumber > 0 && pageNumber <= pdfViewerControl.PageCount)
                    pdfViewerControl.GoToPage(int.Parse((sender as Entry).Text));
                else
                {
                    DisplayAlert("Alert", "Please enter the valid page number.", "OK");
                    (sender as Entry).Text = pdfViewerControl.PageNumber.ToString();
                }
            }
            else
            {
                DisplayAlert("Alert", "Please enter the valid page number.", "OK");
                (sender as Entry).Text = pdfViewerControl.PageNumber.ToString();
            }

        }
        void OnGoToPreviousPageClicked(object sender, EventArgs e)
        {
            //Navigates to previous page of the PDF document.
            if (pdfViewerControl.InputFileStream != null)
                pdfViewerControl.GoToPreviousPage();
        }

        void OnGoToNextPageClicked(object sender, EventArgs e)
        {
            //Navigates to the next page of the PDF document.
            if (pdfViewerControl.InputFileStream != null)
                pdfViewerControl.GoToNextPage();
        }

    }
}
